package es.cgpcosmad.toi18n;

import java.io.IOException;
import java.io.StringReader;
import java.util.Iterator;
import java.util.Properties;
import java.util.logging.Logger;

import org.apache.commons.lang.StringUtils;

import com.google.api.translate.Language;
import com.google.api.translate.Translate;

/**
 * Servicio de traducción
 * @author Carlos García. cgpcosmad@gmail.com
 * @see http://www.carlos-garcia.es
 */
public class I18nService implements java.io.Serializable {
	private static final long serialVersionUID = -6076779395882453758L;
	
	private static final Logger log = Logger.getLogger(I18nService.class.getName());
	private static I18nService instance = new I18nService();
	
	public static I18nService getInstance() {
		return I18nService.instance;
	}
	
	private I18nService(){}
	
	private String translate(String toTranslate, Language sourceLang, Language targetLang) throws Exception{
			return Translate.execute(toTranslate, sourceLang, targetLang);
	}
	
	public String translateAndroid(String toTranslate, Language sourceLang, Language targetLang){
		Properties props 			= Utils.propertiesFromAndroidFormat(toTranslate);
		Properties propsTranslated  = translateProperties(props, sourceLang, targetLang);
		String	   toReturn			= Utils.propertiesToAndroid(propsTranslated);
		
		return toReturn;
	}
	
	
	public String translateProperties(String toTranslate, Language sourceLang, Language targetLang){
		Properties fromProperties = new Properties();
		Properties propsTranslated = null;
		String	   toReturn = null;
		
		try {
			fromProperties.load(new StringReader(toTranslate));
			propsTranslated = this.translateProperties(fromProperties, sourceLang, targetLang);
			toReturn 		= Utils.propertiesToString(propsTranslated);
			
		} catch (IOException ex) {
			// I am force to catch java.lang.Exception because translate API throws that (not subclass)
			log.warning(ex.getMessage());
			throw new IllegalStateException(ex);
		}
		
		return toReturn;
	}
	
	
	private Properties translateProperties(Properties toTranslate, Language sourceLang, Language targetLang){
		Translate.setHttpReferrer("http://toi18n.appspot.com");
		
		Properties propsTranslated = new Properties();
		
		Iterator<String> names = toTranslate.stringPropertyNames().iterator();
		String		name  = null;
		String		value = null;
		String		translated = null;
		
		try {
			while (names.hasNext()){
				name  = names.next();
				value = toTranslate.getProperty(name);
				
				translated  = translate(value, sourceLang, targetLang);
				if (StringUtils.isBlank(translated)){
					translated = name + " ????????";
				}
				
				propsTranslated.put(name, translated);
			}
			
			return propsTranslated;
		} catch (Exception ex) {
			// I am force to catch java.lang.Exception because translate API throws that (not subclass) 
			log.warning(ex.getMessage());
			throw new IllegalStateException(ex);
		}
	}
	
}
