package es.cgpcosmad.toi18n;

import java.io.StringReader;
import java.util.Iterator;
import java.util.Properties;
import java.util.logging.Logger;

import javax.xml.stream.XMLInputFactory;
import javax.xml.stream.XMLStreamConstants;
import javax.xml.stream.XMLStreamException;
import javax.xml.stream.XMLStreamReader;

import org.apache.commons.lang.StringEscapeUtils;

/**
 * @author Carlos García. cgpcosmad@gmail.com
 * @see http://www.carlos-garcia.es
 */
public class Utils {
	private static final Logger log = Logger.getLogger(Utils.class.getName());
	private static final String NL  = System.getProperty("line.separator");
	
	/*
		<?xml version="1.0" encoding="utf-8"?><resources><string name="applicationName">Haaala!</string></resources>	 
	 */
	protected static Properties propertiesFromAndroidFormat(String toTranslate)  {
		Properties		props  = new Properties();
		XMLStreamReader parser = null;  
		String name;
		String value;
		
		try {
			parser = XMLInputFactory.newInstance().createXMLStreamReader(new StringReader(toTranslate));
			while (parser.hasNext()){
				if (parser.next() == XMLStreamConstants.START_ELEMENT){
					if (parser.getLocalName().equals("string")){
						name   = parser.getAttributeValue(null, "name");
						value  = parser.getElementText();
						props.put(name, value);
					}
				}
			}
		} catch (XMLStreamException e) {
			log.warning(e.getMessage());
		} finally {
			try {
				parser.close();
			} catch (Exception ex){}    	
		}		
		
		return props;
	}
	
	protected static String propertiesToAndroid(Properties props)  {
		StringBuilder builder = new StringBuilder(100 * 1024);
		String		  name	  = null;
		String		  value   = null;

		Iterator<String> names =  props.stringPropertyNames().iterator();
		
		builder.append("<?xml version=\"1.0\" encoding=\"utf-8\"?>");
		builder.append(NL);
		builder.append("<resources>");
		while (names.hasNext()){
			name  = names.next();
			value = props.getProperty(name);
			builder.append(NL);
			builder.append("<string name=\"");
			builder.append(name);
			builder.append("\">");
			builder.append(StringEscapeUtils.escapeXml(value));
			builder.append("</string>");
		}
		builder.append(NL);
		builder.append("</resources>");
		
		return builder.toString();
	}
	
	public static String propertiesToString(Properties props) {
		StringBuilder builder = new StringBuilder(75 * 1024);
		String		  name	  = null;
		String		  value   = null;

		Iterator<String> names =  props.stringPropertyNames().iterator();
		
		while (names.hasNext()){
			name  = names.next();
			value = props.getProperty(name);
			builder.append(NL);
			builder.append(name);
			builder.append("=");
			builder.append(value);
		}
		return builder.toString();
	}
}
