package es.cgpcosmad.toi18n.web;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

import javax.annotation.PostConstruct;
import javax.faces.bean.ManagedBean;
import javax.faces.bean.ViewScoped;

import com.google.api.translate.Language;

import es.cgpcosmad.toi18n.I18nService;

@ManagedBean
@ViewScoped
public class HomeView implements Serializable {
	
	private static final long serialVersionUID = -526303295133926077L;

	private LangCtrl    langCtrl;
	private I18nService i18nService;
	
	private String	 textToTranslate;
	private String	 textTranslated;
	
	private boolean	  translating;
	private int 	  inputFormat;
	private Language fromLang;
	private Language targetLang;
	
	
	public HomeView(){
		this.reset();
	}
	
	@PostConstruct
	public void create(){
		this.langCtrl 	 = LangCtrl.getInstance();
		this.i18nService = I18nService.getInstance();
	}
	
	public Language getFromLang() {
		return fromLang;
	}

	public void setFromLang(Language fromLang) {
		this.fromLang = fromLang;
	}

	public Language getTargetLang() {
		return targetLang;
	}

	public void setTargetLang(Language targetLang) {
		this.targetLang = targetLang;
	}


	public List<String> complete(String query) { 
		List<String> available = langCtrl.getLanguages();
		List<String> results   = new ArrayList<String>(32);
		
		query = query.toUpperCase();
		
		for (String lang: available) {
			if (lang.startsWith(query)){
				results.add(lang);
			}
		}
		
		return results;
	}
	 
	
	public String accept(){
		translating = true;
		
		try {
			if ((this.inputFormat == 0) || (this.inputFormat == 2)){
				this.textTranslated = i18nService.translateProperties(this.textToTranslate, fromLang, targetLang);
			} else {
				this.textTranslated = i18nService.translateAndroid(this.textToTranslate, fromLang, targetLang);
			}
			
			return "";
		} finally {
			translating =  false;
		}
	}
	
	
	public void reset(){
		translating = false;
		fromLang	 = null;
		targetLang	 = null;
		textToTranslate = null;
		textTranslated = null;		
	}
	
	public void clearTranslation(){
		textTranslated = null;		
	}
	
	public String getTextToTranslate() {
		return textToTranslate;
	}

	public void setTextToTranslate(String textToTranslate) {
		this.textToTranslate = textToTranslate;
	}


	public String getTextTranslated() {
		return textTranslated;
	}


	public void setTextTranslated(String textTranslated) {
		this.textTranslated = textTranslated;
	}


	public int getInputFormat() {
		return inputFormat;
	}


	public void setInputFormat(int inputFormat) {
		this.inputFormat = inputFormat;
	}


	public boolean isTranslating() {
		return translating;
	}


	public void setTranslating(boolean translating) {
		this.translating = translating;
	}
}